Base geometry object. Before a geometry can be displayed, it must be converted to [Model] by the asset compiler (see [man.AssetCompiler]).

To programmatically create a geometry use [GeometryBuilder].